==> estateplat-common-1.1.0-20160901.111237-172-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzZd.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * Created with IntelliJ IDEA
 * 宗地基本信息.
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:07
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_zd")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzZd implements Serializable {
    @Id
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //地籍号
    @XmlElement(name = "djh")
    private String djh;
    //宗地特征码
    @XmlElement(name = "zdtzm")
    private String zdtzm;
    //坐落
    @XmlElement(name = "zl")
    private String zl;
    //宗地面积
    @XmlElement(name = "zdmj")
    private Double zdmj;
    //面积单位
    @XmlElement(name = "mjdw")
    private String mjdw;
    //用途
    @XmlElement(name = "yt")
    private String yt;
    //等级
    @XmlElement(name = "dj")
    private String dj;
    //价格
    @XmlElement(name = "jg")
    private Double jg;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //权利性质
    @XmlElement(name = "qlxz")
    private String qlxz;
    //权利设定方式
    @XmlElement(name = "qlsdfs")
    private String qlsdfs;
    //容积率
    @XmlElement(name = "rjl")
    private Double rjl;
    //建筑密度
    @XmlElement(name = "jzmd")
    private Double jzmd;
    //建筑限高
    @XmlElement(name = "jzxg")
    private Double jzxg;
    //宗地四至-东
    @XmlElement(name = "zdszd")
    private String zdszd;
    //宗地四至-南
    @XmlElement(name = "zdszn")
    private String zdszn;
    //宗地四至-西
    @XmlElement(name = "zdszx")
    private String zdszx;
    //宗地四至-北
    @XmlElement(name = "zdszb")
    private String zdszb;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //宗地类别
    @XmlElement(name = "zdlb")
    private String zdlb;
    //不动产单元号
    @XmlElement(name = "bdcdyh")
    private String bdcdyh;

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZdtzm() {
        return zdtzm;
    }

    public void setZdtzm(String zdtzm) {
        this.zdtzm = zdtzm;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }

    public Double getJg() {
        return jg;
    }

    public void setJg(Double jg) {
        this.jg = jg;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZdlb() {
        return zdlb;
    }

    public void setZdlb(String zdlb) {
        this.zdlb = zdlb;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
}

==> estateplat-common-1.2.3-20180816.034037-163-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzZd.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA
 * 宗地基本信息.
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:07
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_zd")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzZd implements Serializable {
    @Id
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //地籍号
    @XmlElement(name = "djh")
    private String djh;
    //宗地特征码
    @XmlElement(name = "zdtzm")
    private String zdtzm;
    //坐落
    @XmlElement(name = "zl")
    private String zl;
    //宗地面积
    @XmlElement(name = "zdmj")
    private Double zdmj;
    //面积单位
    @XmlElement(name = "mjdw")
    private String mjdw;
    //用途
    @XmlElement(name = "yt")
    private String yt;
    //等级
    @XmlElement(name = "dj")
    private String dj;
    //价格
    @XmlElement(name = "jg")
    private Double jg;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //权利性质
    @XmlElement(name = "qlxz")
    private String qlxz;
    //权利设定方式
    @XmlElement(name = "qlsdfs")
    private String qlsdfs;
    //容积率
    @XmlElement(name = "rjl")
    private Double rjl;
    //建筑密度
    @XmlElement(name = "jzmd")
    private Double jzmd;
    //建筑限高
    @XmlElement(name = "jzxg")
    private Double jzxg;
    //宗地四至-东
    @XmlElement(name = "zdszd")
    private String zdszd;
    //宗地四至-南
    @XmlElement(name = "zdszn")
    private String zdszn;
    //宗地四至-西
    @XmlElement(name = "zdszx")
    private String zdszx;
    //宗地四至-北
    @XmlElement(name = "zdszb")
    private String zdszb;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //宗地类别
    @XmlElement(name = "zdlb")
    private String zdlb;
    //不动产单元号
    @XmlElement(name = "bdcdyh")
    private String bdcdyh;

    //土地审批时间，登簿时间
    @XmlElement(name = "tdspsj")
    private Date tdspsj;
    //土地登簿人
    @XmlElement(name = "dbr")
    private String  dbr;


    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZdtzm() {
        return zdtzm;
    }

    public void setZdtzm(String zdtzm) {
        this.zdtzm = zdtzm;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }

    public Double getJg() {
        return jg;
    }

    public void setJg(Double jg) {
        this.jg = jg;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZdlb() {
        return zdlb;
    }

    public void setZdlb(String zdlb) {
        this.zdlb = zdlb;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Date getTdspsj() {
        return tdspsj;
    }

    public void setTdspsj(Date tdspsj) {
        this.tdspsj = tdspsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }
}
